<?xml version="1.0" encoding="ISO-8859-1"?>
<!--The abbreviation_file and product_file parameters should be defined if they are not located in their default place-->
<!--The common XSL file.-->
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform" xmlns:saxon="http://icl.com/saxon" extension-element-prefixes="saxon">
	<!--The lang that is used every time a decision has to be made concerning translation-->
	<!--'en' by default; note that the parameter must be surrounded by single quotes!-->
	<xsl:param name="lang" select="'en'" saxon:assignable="yes"/>
	<xsl:param name="single_document"/>
	<!--The current date-->
	<xsl:param name="date"/>
	<!--The URL of the portal XML file that gathers all documents-->
	<xsl:param name="portal_file"/>
	<!--The path of the XML file containing all references descriptions (products, abbreviations)-->
	<xsl:param name="reference_file" select="'Reference.xml'"/>
	<!--The system-dependent path directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_path"/>
	<!--The URL of the directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_url"/>
	<!--The URL of the WedSitor CSS file, used within HTML content files-->
	<xsl:param name="wedsitor_css_url" select="'css/wedsitor.css'"/>
	<!--The URL of the default main CSS file, used within HTML content files-->
	<xsl:param name="main_css_url" select="'css/main.css'"/>
	<!--The URL of the Javascript, used throughout the generated HTML files-->
	<xsl:param name="javascript_url" select="'Common.js'"/>
	<!--
	A flag that tells whether technical details on the content HTML files should be generated. If set, it will considered as true.
	-->
	<xsl:param name="generate_technical_details"/>
	<!--
	A flag that tells whether PHP should be generated. If set, it will considered as true.
	-->
	<xsl:param name="generate_php"/>
	<!--The flag that tells whether frames should be generated or not-->
	<xsl:param name="generate_frames"/>
	<xsl:template match="Info/Authors/Person">
		<xsl:value-of select="Name"/> (<xsl:apply-templates select="Email"/>)</xsl:template>
	<xsl:template match="Email">
		<xsl:if test="count(Type) > 0">
			<xsl:apply-templates select="Type"/>
			<xsl:text> : </xsl:text>
		</xsl:if>
		<a>
			<xsl:attribute name="href">mailto:<xsl:value-of select="node()"/></xsl:attribute>
			<xsl:value-of select="node()"/>
		</a>
	</xsl:template>
	<xsl:template match="Phone">
		<xsl:apply-templates select="Type"/> : <xsl:value-of select="node()"/>
	</xsl:template>
	<xsl:template match="Image">
		<img>
			<xsl:attribute name="alt"><xsl:value-of select="."/></xsl:attribute>
			<xsl:attribute name="src"><xsl:value-of select="ref"/></xsl:attribute>
		</img>
	</xsl:template>
	<xsl:template match="URL">
		<a>
			<xsl:if test="not(@in = 'yes')">
				<xsl:attribute name="class">out</xsl:attribute>
			</xsl:if>
			<xsl:if test="not(@in = 'yes')">
				<xsl:attribute name="target">_blank</xsl:attribute>
			</xsl:if>
			<xsl:attribute name="href"><xsl:choose><xsl:when test="count(ref) = 0"><xsl:value-of select="."/></xsl:when><xsl:otherwise><xsl:value-of select="ref"/></xsl:otherwise></xsl:choose></xsl:attribute>
			<xsl:apply-templates select="text() | *[not(name() = 'ref')]"/>
		</a>
	</xsl:template>
	<xsl:template match="Code">
		<xsl:choose>
			<xsl:when test="@box = 'yes'">
				<pre class="code">
					<xsl:choose>
						<xsl:when test="count(@code) > 0">
							<span class="{@code}">
								<xsl:apply-templates/>
							</span>
						</xsl:when>
						<xsl:otherwise>
							<xsl:apply-templates/>
						</xsl:otherwise>
					</xsl:choose>
				</pre>
			</xsl:when>
			<xsl:otherwise>
				<code>
					<xsl:apply-templates/>
				</code>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Note">
		<xsl:choose>
			<xsl:when test="Title">
				<dl>
					<xsl:apply-templates select="Title"/>
					<dd>
						<xsl:apply-templates select="Body"/>
					</dd>
				</dl>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="note">
					<span class="note">
						<xsl:apply-templates/>
					</span>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="@box='no'">
						<xsl:copy-of select="$note"/>
					</xsl:when>
					<xsl:otherwise>
						<p>Note:<blockquote>
								<xsl:copy-of select="$note"/>
							</blockquote>
						</p>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Example">
		<p>
			<xsl:if test="not(@title = 'no')">Example:</xsl:if>
			<blockquote>
				<span class="example">
					<xsl:apply-templates/>
				</span>
			</blockquote>
		</p>
	</xsl:template>
	<xsl:template match="Warning">
		<p>Warning:
				<blockquote>
				<table class="warning">
					<tr>
						<td>
							<xsl:apply-templates/>
						</td>
					</tr>
				</table>
			</blockquote>
		</p>
	</xsl:template>
	<xsl:template match="Important">
		<p>Important:
				<blockquote>
				<table class="important">
					<tr>
						<td>
							<xsl:apply-templates/>
						</td>
					</tr>
				</table>
			</blockquote>
		</p>
	</xsl:template>
	<xsl:template match="New">
		<span class="new">
			<xsl:apply-templates/>
		</span>
	</xsl:template>
	<xsl:template match="Deprecated">
		<span class="deprecated">
			<xsl:apply-templates/>
		</span>
		<!--table>
			<tr>
				<td>Deprecated since V<xsl:value-of select="Since"/>
				</td>
			</tr>
			<tr>
				<td>
					<xsl:apply-templates select="Body"/>
				</td>
			</tr>
		</table-->
	</xsl:template>
	<xsl:template match="Product">
		<xsl:variable name="text">
			<b>
				<font size="+1">
					<xsl:value-of select="Name"/>
				</font> version <xsl:value-of select="Version"/>
			</b>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="count(Download) > 0">
				<a>
					<xsl:attribute name="href"><xsl:value-of select="Download"/></xsl:attribute>
					<xsl:value-of select="$text"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Path">
		<code>
			<xsl:apply-templates/>
		</code>
	</xsl:template>
	<xsl:template match="p">
		<p>
			<xsl:apply-templates/>
		</p>
	</xsl:template>
	<xsl:template match="em">
		<em>
			<xsl:apply-templates/>
		</em>
	</xsl:template>
	<xsl:template match="b">
		<b>
			<xsl:apply-templates/>
		</b>
	</xsl:template>
	<xsl:template match="strong">
		<strong>
			<xsl:apply-templates/>
		</strong>
	</xsl:template>
	<xsl:template match="cite">
		<em>
			<xsl:apply-templates/>
		</em>
	</xsl:template>
	<xsl:template match="s">
		<s>
			<xsl:apply-templates/>
		</s>
	</xsl:template>
	<xsl:template match="u">
		<u>
			<xsl:apply-templates/>
		</u>
	</xsl:template>
	<xsl:template match="sup">
		<sup>
			<xsl:apply-templates/>
		</sup>
	</xsl:template>
	<xsl:template match="Lang">
		<xsl:variable name="language">
			<xsl:call-template name="print_language"/>
		</xsl:variable>
		<xsl:if test="$language = '' or @xml:lang = $language">
			<xsl:apply-templates/>
		</xsl:if>
	</xsl:template>
	<xsl:template match="Date">
		<xsl:if test="count(@day) > 0">
			<xsl:number format="01" value="@day"/>.</xsl:if>
		<xsl:if test="count(@month) > 0">
			<xsl:number format="01" value="@month"/>.</xsl:if>
		<xsl:value-of select="@year"/>
	</xsl:template>
	<xsl:template match="Items">
		<ul>
			<xsl:apply-templates select="Item"/>
		</ul>
	</xsl:template>
	<xsl:template match="Item">
		<li>
			<xsl:apply-templates/>
		</li>
	</xsl:template>
	<xsl:template match="Ref">
		<xsl:variable name="file_reference" select="document($reference_file)//Reference[@ID = current()/@IDREF]"/>
		<xsl:variable name="inline_references" select="//Reference[@ID = current()/@IDREF]"/>
		<xsl:variable name="inline_reference" select="$inline_references[1]"/>
		<xsl:choose>
			<xsl:when test="$inline_reference">
				<xsl:call-template name="_print_text_reference">
					<xsl:with-param name="reference" select="$inline_reference"/>
				</xsl:call-template>
			</xsl:when>
			<xsl:otherwise>
				<xsl:call-template name="_print_text_reference">
					<xsl:with-param name="reference" select="$file_reference"/>
				</xsl:call-template>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Reference">
		<xsl:call-template name="_print_text_reference">
			<xsl:with-param name="reference" select="."/>
		</xsl:call-template>
	</xsl:template>
	<xsl:template match="Doc">
		<xsl:choose>
			<xsl:when test="@inline = 'yes'">
				<xsl:if test="not(text())">
					<xsl:message>Warning: text within '<xsl:copy-of select="."/>' will be discarded</xsl:message>
				</xsl:if>
				<xsl:variable name="xml_document">
					<xsl:call-template name="print_xml_document_source">
						<xsl:with-param name="id" select="@IDREF"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="@section">
						<xsl:apply-templates select="document($xml_document)/Document/Body//Section[@ID = current()/@section]"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="document($xml_document)/Document/Body"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<a target="_top">
					<xsl:variable name="document_url">
						<xsl:call-template name="print_document_url">
							<xsl:with-param name="id" select="@IDREF"/>
							<xsl:with-param name="xml:lang" select="@xml:lang"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:attribute name="href"><xsl:choose><xsl:when test="@section"><xsl:text>javascript:openFrameSetAtAnchor('</xsl:text><xsl:value-of select="$document_url"/><xsl:text>', '</xsl:text><xsl:value-of select="@section"/><xsl:text>')</xsl:text></xsl:when><xsl:otherwise><xsl:value-of select="$document_url"/></xsl:otherwise></xsl:choose></xsl:attribute>
					<xsl:choose>
						<xsl:when test="string-length(text()) > 0">
							<xsl:value-of select="."/>
						</xsl:when>
						<xsl:otherwise>
							<xsl:choose>
								<xsl:when test="$single_document">
									<xsl:call-template name="print_document_title_from_xml">
										<xsl:with-param name="id" select="@IDREF"/>
										<xsl:with-param name="xml:lang" select="@xml:lang"/>
									</xsl:call-template>
								</xsl:when>
								<xsl:otherwise>
									<xsl:variable name="portal_documents">
										<xsl:call-template name="print_portal_documents"/>
									</xsl:variable>
									<xsl:variable name="portal_document" select="$portal_documents/Document[@IDREF = current()/@IDREF and (not(current()/@xml:lang) or @xml:lang = current()/@xml:lang)]"/>
									<xsl:if test="count($portal_document) = 0">
										<xsl:message>Error: Doc element <xsl:copy-of select="$portal_document"/> does not correspond to any available document!</xsl:message>
									</xsl:if>
									<xsl:call-template name="print_document_title">
										<xsl:with-param name="portal_document" select="$portal_document"/>
									</xsl:call-template>
								</xsl:otherwise>
							</xsl:choose>
						</xsl:otherwise>
					</xsl:choose>
				</a>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<xsl:template match="Sect">
		<a href="#{@IDREF}">
			<xsl:apply-templates/>
		</a>
	</xsl:template>
	<xsl:template match="PHP">
		<xsl:choose>
			<xsl:when test="$generate_php = 'yes'">
				<xsl:text disable-output-escaping="yes"><![CDATA[<?php ]]></xsl:text>
				<xsl:value-of select="." disable-output-escaping="yes"/>
				<xsl:text disable-output-escaping="yes"><![CDATA[?>]]></xsl:text>
			</xsl:when>
			<xsl:otherwise>
				<xsl:message>Warning: the document with ID <xsl:value-of select="/Document/@ID"/> contains a PHP element!</xsl:message>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the Section name that is used to reference the section-->
	<!--the current node must be a Section element; or the section parameter must point to a Section element-->
	<xsl:template name="print_section_aname">
		<xsl:param name="section"/>
		<xsl:choose>
			<xsl:when test="$section = ''">
				<xsl:variable name="actual_section" select="current()"/>
				<xsl:choose>
					<xsl:when test="count($actual_section/@ID) > 0">
						<xsl:value-of select="$actual_section/@ID"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="_print_section_index">
							<xsl:with-param name="section" select="$actual_section"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="actual_section" select="$section"/>
				<xsl:choose>
					<xsl:when test="count($actual_section/@ID) > 0">
						<xsl:value-of select="$actual_section/@ID"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="_print_section_index">
							<xsl:with-param name="section" select="$actual_section"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the Section index if no ID is provided to the section-->
	<!--the current node must be a Section element; or the section parameter must point to a Section element-->
	<xsl:template name="_print_section_index">
		<xsl:param name="section"/>
		<xsl:choose>
			<xsl:when test="not($section)">
				<xsl:variable name="actual_section" select="current()"/>
				<xsl:for-each select="$actual_section/ancestor-or-self::Section">
					<xsl:value-of select="count(preceding-sibling::Section) + 1"/>.</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="actual_section" select="$section"/>
				<xsl:for-each select="$actual_section/ancestor-or-self::Section">
					<xsl:value-of select="count(preceding-sibling::Section) + 1"/>.</xsl:for-each>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the Reference element as plain XML-->
	<!--the reference id must be given as a parameter-->
	<xsl:template name="print_reference">
		<xsl:param name="reference_id"/>
		<xsl:variable name="file_reference" select="document($reference_file)//Reference[@ID = $reference_id]"/>
		<xsl:variable name="inline_reference" select="//Reference[@ID = $reference_id]"/>
		<xsl:choose>
			<xsl:when test="$inline_reference">
				<xsl:copy-of select="$inline_reference"/>
			</xsl:when>
			<xsl:when test="$file_reference">
				<xsl:copy-of select="$file_reference"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:message>
					<xsl:text>Problem with Ref '</xsl:text>
					<xsl:value-of select="$reference_id"/>
					<xsl:text>'</xsl:text>
				</xsl:message>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the inline text of the reference-->
	<!--the current node should be an element with some attributes-->
	<!--the parameter reference must be defined and should point to a Reference element-->
	<xsl:template name="_print_text_reference">
		<xsl:param name="reference"/>
		<xsl:variable name="text">
			<xsl:choose>
				<xsl:when test="count($reference/Name/Abreviation) > 0">
					<xsl:choose>
						<xsl:when test="@long = 'yes'">
							<xsl:call-template name="print_abbreviation_description">
								<xsl:with-param name="abbreviation" select="$reference/Name/Abreviation"/>
							</xsl:call-template>
							<xsl:if test="@p = 'yes'">
								<xsl:text> (</xsl:text>
								<xsl:call-template name="print_abbreviation_acronym">
									<xsl:with-param name="abbreviation" select="$reference/Name/Abreviation"/>
								</xsl:call-template>
								<xsl:text>)</xsl:text>
							</xsl:if>
						</xsl:when>
						<xsl:otherwise>
							<abbr>
								<span class="abbreviation">
									<xsl:attribute name="title"><xsl:call-template name="print_abbreviation_description"><xsl:with-param name="abbreviation" select="$reference/Name/Abreviation"/></xsl:call-template></xsl:attribute>
									<xsl:call-template name="print_abbreviation_acronym">
										<xsl:with-param name="abbreviation" select="$reference/Name/Abreviation"/>
									</xsl:call-template>
								</span>
							</abbr>
						</xsl:otherwise>
					</xsl:choose>
				</xsl:when>
				<xsl:otherwise>
					<xsl:apply-templates select="$reference/Name"/>
				</xsl:otherwise>
			</xsl:choose>
			<xsl:if test="count(@version) > 0 or count($reference/Version) > 0">
				<xsl:text>&#160;</xsl:text>
				<xsl:choose>
					<xsl:when test="count(@version) > 0">
						<xsl:value-of select="@version"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:value-of select="$reference/Version"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:if>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="@a = 'yes' and count($reference/@href) > 0">
				<a href="{$reference/@href}">
					<xsl:if test="not(@in = 'yes')">
						<xsl:attribute name="class">out</xsl:attribute>
						<xsl:attribute name="target">_blank</xsl:attribute>
					</xsl:if>
					<xsl:copy-of select="$text"/>
				</a>
			</xsl:when>
			<xsl:otherwise>
				<xsl:copy-of select="$text"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the declaration of the necessary CSS files that are being used through the generated HTML pages-->
	<xsl:template name="print_css_link_part">
		<link rel="StyleSheet" type="text/css">
			<xsl:attribute name="href"><xsl:call-template name="_print_wedsitor_stylesheet_path"/></xsl:attribute>
		</link>
		<link rel="StyleSheet" type="text/css">
			<xsl:attribute name="href"><xsl:call-template name="_print_content_stylesheet_path"/></xsl:attribute>
		</link>
	</xsl:template>
	<!--Prints the path of the WedSitor CSS stylesheet file used on the generated HTML pages-->
	<xsl:template name="_print_wedsitor_stylesheet_path">
		<xsl:value-of select="$wedsitor_css_url"/>
	</xsl:template>
	<!--Prints the path of the content CSS stylesheet file used on the generated HTML pages-->
	<xsl:template name="_print_content_stylesheet_path">
		<xsl:value-of select="$main_css_url"/>
	</xsl:template>
	<!--Prints the path of the Javascript file used and included on the generated HTML pages-->
	<xsl:template name="_print_javascript_path">
		<xsl:value-of select="$javascript_url"/>
	</xsl:template>
	<!--Prints the description of the abbreviation-->
	<!--the abbreviation must be given as a parameter; the lang parameter should be set-->
	<xsl:template name="print_abbreviation_description">
		<xsl:param name="abbreviation"/>
		<xsl:choose>
			<xsl:when test="count($abbreviation/Lang) > 0">
				<xsl:apply-templates select="$abbreviation/Lang[@xml:lang = $lang]"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates select="$abbreviation"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the abbreviation acronym-->
	<!--the abbreviation must be given as a parameter; the lang parameter should also be set-->
	<xsl:template name="print_abbreviation_acronym">
		<xsl:param name="abbreviation"/>
		<xsl:choose>
			<xsl:when test="count($abbreviation/Lang) > 0">
				<xsl:value-of select="$abbreviation/Lang[@xml:lang = $lang]/@ID"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:value-of select="$abbreviation/@ID"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the system-dependant path or the URL of the generated HTML menu file for a given document. The menu is present on the left and provides shortcuts to the content-->
	<!--the portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined-->
	<!--the 'url' parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--the 'relative' parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_html_menu_file_path">
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!--xsl:variable name="xml_file">
			<xsl:call-template name="print_xml_file_path">
				<xsl:with-param name="document_id" select="$portal_document/@IDREF"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:value-of select="document($xml_file)/Document/@ID"/-->
		<xsl:value-of select="$portal_document/@IDREF"/>
		<xsl:text>_menu.html</xsl:text>
	</xsl:template>
	<!--Prints the system-dependant path or the URL of the generated HTML index file for a given document. The index enables to navigate throughout the site-->
	<!--the portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined-->
	<!--the 'url' parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--the 'relative' parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_html_index_file_path">
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!--xsl:variable name="xml_file">
			<xsl:call-template name="print_xml_file_path">
				<xsl:with-param name="document_id" select="$portal_document/@IDREF"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="document" select="document($xml_file)/Document[@ID]"/>
		<xsl:value-of select="@ID"/-->
		<xsl:value-of select="$portal_document/@IDREF"/>
		<xsl:if test="$portal_document/@xml:lang">
			<xsl:text>_</xsl:text>
			<xsl:value-of select="$portal_document/@xml:lang"/>
		</xsl:if>
		<xsl:text>_index.</xsl:text>
		<xsl:choose>
			<xsl:when test="$generate_php = 'yes'">php</xsl:when>
			<xsl:otherwise>html</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the path of the generated HTML frame file for a given document. The frame excludes the top index-->
	<!--The portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_html_inner_frame_file_path">
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!--xsl:variable name="xml_file">
			<xsl:call-template name="print_xml_file_path">
				<xsl:with-param name="document_id" select="$portal_document/@IDREF"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:variable name="document" select="document($xml_file)/Document[@ID]"/>
		<xsl:value-of select="@ID"/-->
		<xsl:value-of select="$portal_document/@IDREF"/>
		<xsl:choose>
			<xsl:when test="$portal_document/@xml:lang">
				<xsl:text>_</xsl:text>
				<xsl:value-of select="$portal_document/@xml:lang"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:text>_frame</xsl:text>
			</xsl:otherwise>
		</xsl:choose>
		<xsl:text>.html</xsl:text>
	</xsl:template>
	<!--Prints the path of the generated HTML content file for a given document-->
	<!--The portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_html_content_file_path">
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="string($portal_document/@IDREF) = ''">
			<xsl:message>Warning in print_html_content_file_path: the portal_document <xsl:copy-of select="$portal_document"/> does not have a IDREF attribute</xsl:message>
		</xsl:if>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:value-of select="$portal_document/@IDREF"/>
		<xsl:text>_content</xsl:text>
		<xsl:if test="$portal_document/@xml:lang">
			<xsl:text>_</xsl:text>
			<xsl:value-of select="$portal_document/@xml:lang"/>
		</xsl:if>
		<xsl:text>.</xsl:text>
		<xsl:choose>
			<xsl:when test="$generate_php = 'yes'">php</xsl:when>
			<xsl:otherwise>html</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the path of the generated HTML file for a given document. The HTML file includes the top index-->
	<!--The portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_html_top_file_path">
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="string($portal_document/@IDREF) = ''">
			<xsl:message>Warning in print_html_top_file_path: the portal_document <xsl:copy-of select="$portal_document"/> does not have a IDREF attribute</xsl:message>
		</xsl:if>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<!--xsl:variable name="xml_file">
					<xsl:call-template name="print_xml_file_path">
						<xsl:with-param name="document_id" select="$portal_document/@IDREF"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:value-of select="document($xml_file)/Document/@ID"/-->
		<xsl:value-of select="$portal_document/@IDREF"/>
		<xsl:if test="$portal_document/@xml:lang">
			<xsl:text>_</xsl:text>
			<xsl:value-of select="$portal_document/@xml:lang"/>
		</xsl:if>
		<xsl:text>_top.html</xsl:text>
	</xsl:template>
	<!--
	Prints the path of the target HTML file that should be used in order to display the page properly, for a given document.
	The portal_document must be given as a parameter and be equal to a Document element with IDREF attribute defined.
	The url parameter may be provided , and when equal to 'yes', the URL of the file is generated.
	The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated.
	The idref and xml:lang parameters may be provided: in this case, the portal_document parameter is discarded.
	-->
	<xsl:template name="print_html_target_file_path">
		<xsl:param name="idref"/>
		<xsl:param name="xml:lang"/>
		<xsl:param name="portal_document"/>
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:choose>
			<xsl:when test="not($idref = '')">
				<xsl:variable name="portal_topics">
					<xsl:call-template name="print_portal_topics"/>
				</xsl:variable>
				<xsl:variable name="document" select="$portal_topics/Topic/Documents/Document[@IDREF = $idref and (not($xml:lang) or @xml:lang = $xml:lang)]"/>
				<xsl:choose>
					<xsl:when test="not($generate_frames) and not($document/@type = 'HTML')">
						<xsl:call-template name="print_html_content_file_path">
							<xsl:with-param name="portal_document" select="$document"/>
							<xsl:with-param name="url" select="$url"/>
							<xsl:with-param name="relative" select="$relative"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="print_html_top_file_path">
							<xsl:with-param name="portal_document" select="$document"/>
							<xsl:with-param name="url" select="$url"/>
							<xsl:with-param name="relative" select="$relative"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:if test="string($portal_document/@IDREF) = ''">
					<xsl:message>Warning in print_html_target_file_path: the portal_document <xsl:copy-of select="$portal_document"/> does not have a IDREF attribute</xsl:message>
				</xsl:if>
				<xsl:choose>
					<xsl:when test="not($generate_frames) and not($portal_document/@type = 'HTML')">
						<xsl:call-template name="print_html_content_file_path">
							<xsl:with-param name="portal_document" select="$portal_document"/>
							<xsl:with-param name="url" select="$url"/>
							<xsl:with-param name="relative" select="$relative"/>
						</xsl:call-template>
					</xsl:when>
					<xsl:otherwise>
						<xsl:call-template name="print_html_top_file_path">
							<xsl:with-param name="portal_document" select="$portal_document"/>
							<xsl:with-param name="url" select="$url"/>
							<xsl:with-param name="relative" select="$relative"/>
						</xsl:call-template>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the title of the document.
	The id and the xml:lang parameters must be provided.
	-->
	<xsl:template name="print_document_title_from_xml">
		<xsl:param name="id"/>
		<xsl:param name="xml:lang"/>
		<xsl:variable name="xml_file">
			<xsl:call-template name="print_xml_document_source">
				<xsl:with-param name="id" select="$id"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:choose>
			<xsl:when test="count(document($xml_file)/Document/Title[@xml:lang = $xml:lang]) > 0">
				<xsl:variable name="title" select="document($xml_file)/Document/Title[@xml:lang = $xml:lang]"/>
				<xsl:choose>
					<xsl:when test="count($title/@short) > 0">
						<xsl:value-of select="$title/@short"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="$title"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="title" select="document($xml_file)/Document/Title"/>
				<xsl:choose>
					<xsl:when test="count($title/@short) > 0">
						<xsl:value-of select="$title/@short"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates select="$title"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the title of the document-->
	<!--The portal_document must be given as a parameter-->
	<xsl:template name="print_document_title">
		<xsl:param name="portal_document"/>
		<xsl:choose>
			<xsl:when test="$portal_document/@type = 'HTML'">
				<xsl:value-of select="URL"/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="xml_file">
					<xsl:call-template name="print_xml_document_source">
						<xsl:with-param name="id" select="$portal_document/@IDREF"/>
					</xsl:call-template>
				</xsl:variable>
				<xsl:choose>
					<xsl:when test="count(document($xml_file)/Document/Title[@xml:lang = $portal_document/@xml:lang]) > 0">
						<xsl:variable name="title" select="document($xml_file)/Document/Title[@xml:lang = $portal_document/@xml:lang]"/>
						<xsl:choose>
							<xsl:when test="count($title/@short) > 0">
								<xsl:value-of select="$title/@short"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="$title"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:when>
					<xsl:otherwise>
						<xsl:variable name="title" select="document($xml_file)/Document/Title"/>
						<xsl:choose>
							<xsl:when test="count($title/@short) > 0">
								<xsl:value-of select="$title/@short"/>
							</xsl:when>
							<xsl:otherwise>
								<xsl:apply-templates select="$title"/>
							</xsl:otherwise>
						</xsl:choose>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the name of the HTML site indices file presented all references-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_indices_file_path">
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:text>indices.html</xsl:text>
	</xsl:template>
	<!--Prints the name of the HTML site map file containing the map of the site-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="print_sitemap_file_path">
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:text>sitemap.</xsl:text>
		<xsl:choose>
			<xsl:when test="$generate_php = 'yes'">php</xsl:when>
			<xsl:otherwise>html</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--Prints the full portal document topics, which describes the web site architecture of the content. Ideal for adding integrated topics-->
	<xsl:template name="print_portal_topics">
		<xsl:copy-of select="document($portal_file)/Portal/Topics/Topic"/>
		<Topic title="Navigation">
			<Documents>
				<Document IDREF="sitemap" type="HTML" main="yes">
					<URL>
						<xsl:attribute name="ref"><xsl:call-template name="print_sitemap_file_path"><xsl:with-param name="url" select="'yes'"/><xsl:with-param name="relative" select="'yes'"/></xsl:call-template></xsl:attribute>Site map</URL>
				</Document>
				<Document IDREF="indices" type="HTML">
					<URL>
						<xsl:attribute name="ref"><xsl:call-template name="print_indices_file_path"><xsl:with-param name="url" select="'yes'"/><xsl:with-param name="relative" select="'yes'"/></xsl:call-template></xsl:attribute>Index</URL>
				</Document>
			</Documents>
		</Topic>
		<xsl:if test="$generate_php = 'yes'">
			<Topic title="Admin">
				<Documents>
					<Document IDREF="statistics" main="yes"/>
				</Documents>
			</Topic>
		</xsl:if>
	</xsl:template>
	<!--Prints all the portal documents, which gathers all documents handled on the underlying web site-->
	<xsl:template name="print_portal_documents">
		<xsl:copy-of select="document($portal_file)//Document"/>
		<Document IDREF="sitemap" type="HTML" main="yes">
			<URL>
				<xsl:attribute name="ref"><xsl:call-template name="print_sitemap_file_path"><xsl:with-param name="url" select="'yes'"/><xsl:with-param name="relative" select="'yes'"/></xsl:call-template></xsl:attribute>Site map</URL>
		</Document>
		<Document IDREF="indices" type="HTML">
			<URL>
				<xsl:attribute name="ref"><xsl:call-template name="print_indices_file_path"><xsl:with-param name="url" select="'yes'"/><xsl:with-param name="relative" select="'yes'"/></xsl:call-template></xsl:attribute>Index</URL>
		</Document>
		<xsl:if test="$generate_php = 'yes'">
			<Document IDREF="statistics" main="yes"/>
		</xsl:if>
	</xsl:template>
	<!--Prints the copyright for this site generator-->
	<xsl:template name="print_content_copyright">
		<div class="copyright">Pages generated by <strong>
				<i>
					<a href="http://wedsitor.free.fr" target="_blank">WedSitor</a>
				</i>
			</strong>
		</div>
	</xsl:template>
	<!--Sets the current language-->
	<!--The language parameter must be provided-->
	<xsl:template name="set_language">
		<xsl:param name="language"/>
		<saxon:assign name="lang" select="$language"/>
	</xsl:template>
	<!--Prints the current language-->
	<xsl:template name="print_language">
		<xsl:value-of select="$lang"/>
	</xsl:template>
	<!--Prints the PHP header if allowed-->
	<xsl:template name="print_php_header">
		<xsl:if test="$generate_php = 'yes'">
			<xsl:text disable-output-escaping="yes"><![CDATA[<?php
session_start();
?>]]></xsl:text>
		</xsl:if>
	</xsl:template>
	<!--Prints the full portal document top element, which describes the web site overall information-->
	<xsl:template name="print_portal_information">
		<xsl:copy-of select="document($portal_file)/Portal"/>
	</xsl:template>
	<!--Prints the name of the file containing the index resource, which is displayed by default-->
	<xsl:template name="print_index_file_name">
		<xsl:text>index.</xsl:text>
		<xsl:choose>
			<xsl:when test="$generate_php = 'yes'">php</xsl:when>
			<xsl:otherwise>html</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	This templates prints a portal document 'Document' from its identifier.
	The id and xml:lang parameters are expected.
	-->
	<xsl:template name="convert_id_into_portal_document">
		<xsl:param name="id"/>
		<xsl:param name="xml:lang"/>
		<xsl:choose>
			<xsl:when test="$single_document">
				<Document>
					<xsl:attribute name="IDREF"><xsl:value-of select="$id"/></xsl:attribute>
					<xsl:if test="$xml:lang">
						<xsl:attribute name="xml:lang"><xsl:value-of select="$xml:lang"/></xsl:attribute>
					</xsl:if>
				</Document>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="portal_documents">
					<xsl:call-template name="print_portal_documents"/>
				</xsl:variable>
				<xsl:variable name="portal_document" select="$portal_documents/Document[@IDREF = current()/@IDREF and (not(current()/@xml:lang) or @xml:lang = current()/@xml:lang)]"/>
				<xsl:choose>
					<xsl:when test="count($portal_document) = 0">
						<xsl:message>Error: Doc element <xsl:value-of select="$id"/> does not correspond to any available document!</xsl:message>
					</xsl:when>
					<xsl:otherwise>
						<xsl:copy-of select="$portal_document"/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
</xsl:stylesheet>
