<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
	<!--The main document transformations-->
	<xsl:import href="Document.xsl"/>
	<!--The URL of the portal XML file that gathers all documents-->
	<xsl:param name="portal_file"/>
	<!--The system-dependant path directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_path"/>
	<!--The URL of the directory where the HTML generated files will be output-->
	<xsl:param name="generated_directory_url"/>
	<!--A flag that tells whether PHP should be generated (possible values 'yes' and 'no'-->
	<xsl:param name="generate_php"/>
	<!--The flag that tells whether frames should be generated or not-->
	<xsl:param name="generate_frames"/>
	<!--The flag that indicates whether only the content should be generated, no the navigational part. If true, then each XML described in the XML portal element will be rendered into HTML-->
	<xsl:param name="no_navigation"/>
	<xsl:template match="Portal">
		<xsl:call-template name="_write_statistics_xml_document_file"/>
		<xsl:choose>
			<xsl:when test="$no_navigation">
				<xsl:variable name="topics">
					<xsl:copy-of select="document($portal_file)/Portal/Topics/Topic"/>
					<xsl:copy-of select="document($portal_file)/Portal/Document"/>
				</xsl:variable>
				<xsl:for-each select="$topics//Document[not(@type = 'HTML')]">
					<xsl:variable name="xml_file">
						<xsl:call-template name="print_xml_document_source">
							<xsl:with-param name="id" select="@IDREF"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:apply-templates select="document($xml_file)/Document">
						<xsl:with-param name="portal_document" select="."/>
					</xsl:apply-templates>
				</xsl:for-each>
			</xsl:when>
			<xsl:otherwise>
				<xsl:variable name="augmented_topics">
					<xsl:call-template name="print_portal_topics"/>
					<xsl:copy-of select="Topics/Topic"/>
				</xsl:variable>
				<xsl:for-each select="$augmented_topics//Document[not(@type = 'HTML')]">
					<xsl:variable name="xml_file">
						<xsl:call-template name="print_xml_document_source">
							<xsl:with-param name="id" select="@IDREF"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:apply-templates select="document($xml_file)/Document">
						<xsl:with-param name="portal_document" select="."/>
					</xsl:apply-templates>
				</xsl:for-each>
				<xsl:for-each select="$augmented_topics//Document[@type = 'HTML']">
					<xsl:variable name="top_file">
						<xsl:call-template name="print_html_top_file_path">
							<xsl:with-param name="portal_document" select="."/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:variable name="index_file">
						<xsl:call-template name="print_html_index_file_path">
							<xsl:with-param name="portal_document" select="."/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:document href="{$index_file}">
						<xsl:call-template name="write_index">
							<xsl:with-param name="portal_document" select="."/>
						</xsl:call-template>
					</xsl:document>
					<xsl:document href="{$top_file}">
						<xsl:call-template name="write_top">
							<xsl:with-param name="index_file">
								<xsl:call-template name="print_html_index_file_path">
									<xsl:with-param name="portal_document" select="."/>
									<xsl:with-param name="url" select="'yes'"/>
									<xsl:with-param name="relative" select="'yes'"/>
								</xsl:call-template>
							</xsl:with-param>
							<xsl:with-param name="inner_frame_file" select="URL/@ref"/>
						</xsl:call-template>
					</xsl:document>
				</xsl:for-each>
				<xsl:call-template name="_print_index_new"/>
				<xsl:call-template name="_print_site_map"/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>
	<!--
	Prints the site index HTML file.
	The current node should belong to the portal XML file.
	-->
	<xsl:template name="_print_index_new">
		<xsl:variable name="main_index_file">
			<xsl:value-of select="$generated_directory_path"/>
			<xsl:call-template name="print_index_file_name"/>
		</xsl:variable>
		<xsl:document href="{$main_index_file}">
			<xsl:call-template name="print_php_header"/>
			<html>
				<head>
					<meta name="robots" content="index, follow"/>
					<xsl:call-template name="print_css_link_part"/>
					<script type="text/javascript" language="javascript">
						<xsl:attribute name="src"><xsl:call-template name="_print_javascript_path"/></xsl:attribute>
					</script>
					<title>
						<xsl:value-of select="/Portal/Title"/>
					</title>
				</head>
				<body>
					<xsl:variable name="main_portal_document" select="/Portal/Document"/>
					<a name="tothetop"/>
					<xsl:call-template name="print_top_banner_new"/>
					<div class="tabs">
						<xsl:variable name="topics">
							<xsl:call-template name="print_portal_topics"/>
						</xsl:variable>
						<xsl:for-each select="$topics/Topic">
							<xsl:variable name="main_document" select="Documents/Document[@main = 'yes']"/>
							<xsl:variable name="html_file">
								<xsl:call-template name="print_html_target_file_path">
									<xsl:with-param name="portal_document" select="$main_document"/>
									<xsl:with-param name="url" select="'yes'"/>
									<xsl:with-param name="relative" select="'yes'"/>
								</xsl:call-template>
							</xsl:variable>
							<a class="unselected">
								<xsl:attribute name="href"><xsl:value-of select="$html_file"/></xsl:attribute>
								<xsl:value-of select="@title"/>
							</a>
						</xsl:for-each>
					</div>
					<div class="underTabs">You are on the home page of the site</div>
					<xsl:call-template name="print_login_part_in">
						<xsl:with-param name="portal_document" select="$main_portal_document"/>
					</xsl:call-template>
					<xsl:call-template name="_print_php_audit">
						<xsl:with-param name="portal_document" select="$main_portal_document"/>
					</xsl:call-template>
					<xsl:call-template name="_print_content_top_part"/>
					<xsl:variable name="xml_file">
						<xsl:call-template name="print_xml_document_source">
							<xsl:with-param name="id" select="$main_portal_document/@IDREF"/>
						</xsl:call-template>
					</xsl:variable>
					<xsl:for-each select="document($xml_file)/Document">
						<xsl:call-template name="_print_content_body_part_from_xml"/>
					</xsl:for-each>
					<xsl:call-template name="_print_content_bottom_part"/>
					<xsl:call-template name="_print_content_audit_part"/>
					<xsl:call-template name="print_login_part_out">
						<xsl:with-param name="portal_document" select="$main_portal_document"/>
					</xsl:call-template>
					<xsl:call-template name="print_content_copyright"/>
				</body>
			</html>
		</xsl:document>
	</xsl:template>
	<!--Prints the site index HTML file-->
	<!--The current node must be an element of the portal XML file-->
	<xsl:template name="_print_index_old">
		<xsl:variable name="main_portal_document" select="//Topic[@main = 'yes']//Document[@main = 'yes']"/>
		<xsl:variable name="main_index_file">
			<xsl:value-of select="$generated_directory_path"/>
			<xsl:call-template name="print_index_file_name"/>
		</xsl:variable>
		<xsl:document href="{$main_index_file}">
			<html>
				<head>
					<meta name="robots" content="index, follow"/>
					<xsl:call-template name="print_css_link_part"/>
					<title>
						<xsl:value-of select="/Portal/Title"/>
					</title>
				</head>
				<body>
					<div align="center">
						<font size="24">
							<xsl:value-of select="/Portal/Title"/>
						</font>
					</div>
					<xsl:variable name="top_file">
						<xsl:call-template name="print_html_target_file_path">
							<xsl:with-param name="portal_document" select="$main_portal_document"/>
							<xsl:with-param name="url" select="'yes'"/>
							<xsl:with-param name="relative" select="'yes'"/>
						</xsl:call-template>
					</xsl:variable>
					<br/>
					<br/>
					<br/>
					<br/>
					<br/>
					<br/>
					<br/>
					<div align="center">
						<a href="{$top_file}">
							<font size="18">
								<xsl:text>ENTER</xsl:text>
							</font>
						</a>
					</div>
				</body>
			</html>
		</xsl:document>
	</xsl:template>
	<!--Prints the site map HTML file-->
	<!--The current node must be an element of the portal XML file-->
	<xsl:template name="_print_site_map">
		<xsl:variable name="site_map_file">
			<xsl:call-template name="print_sitemap_file_path">
				<xsl:with-param name="url" select="'no'"/>
				<xsl:with-param name="relative" select="'no'"/>
			</xsl:call-template>
		</xsl:variable>
		<xsl:document href="{$site_map_file}">
			<html>
				<head>
					<meta name="robots" content="noindex, follow"/>
					<xsl:call-template name="print_css_link_part"/>
					<title>Site Map</title>
				</head>
				<body>
					<p>Here is the map of this site.</p>
					<xsl:call-template name="_print_site_map_content"/>
					<xsl:call-template name="print_content_copyright"/>
				</body>
			</html>
		</xsl:document>
	</xsl:template>
	<!--Prints the table content of the site map HTML file-->
	<!--The current node must be an element of the portal XML file-->
	<xsl:template name="_print_site_map_content">
		<xsl:variable name="target" select="'_top'"/>
		<xsl:variable name="augmented_topics">
			<xsl:copy-of select="//Topics/Topic"/>
		</xsl:variable>
		<table class="map">
			<xsl:for-each select="$augmented_topics/Topic">
				<tr>
					<th rowspan="{count(Documents/Document) + 1}">
						<xsl:value-of select="@title"/>
					</th>
				</tr>
				<xsl:for-each select="Documents/Document">
					<tr>
						<td>
							<strong>
								<a target="{$target}">
									<xsl:attribute name="href"><xsl:call-template name="print_html_target_file_path"><xsl:with-param name="portal_document" select="."/><xsl:with-param name="url" select="'yes'"/><xsl:with-param name="relative" select="'yes'"/></xsl:call-template></xsl:attribute>
									<xsl:call-template name="print_document_title">
										<xsl:with-param name="portal_document" select="."/>
									</xsl:call-template>
								</a>
							</strong>
							<xsl:if test="not(@type = 'HTML')">
								<xsl:variable name="xml_file">
									<xsl:call-template name="print_xml_document_source">
										<xsl:with-param name="id" select="@IDREF"/>
									</xsl:call-template>
								</xsl:variable>
								<blockquote>
									<xsl:apply-templates select="document($xml_file)/Document/Abstract"/>
								</blockquote>
							</xsl:if>
						</td>
					</tr>
				</xsl:for-each>
			</xsl:for-each>
		</table>
	</xsl:template>
	<!--Prints the name of the XML document file concerning the statistics of the generated web site-->
	<!--The url parameter may be provided , and when equal to 'yes', the URL of the file is generated-->
	<!--The relative parameter may be provided, and when equal to 'yes', a relative path or URL will be generated-->
	<xsl:template name="_print_xml_document_statistics_file_path">
		<xsl:param name="url"/>
		<xsl:param name="relative"/>
		<xsl:if test="not($relative = 'yes')">
			<xsl:choose>
				<xsl:when test="$url = 'yes'">
					<xsl:value-of select="$generated_directory_url"/>
				</xsl:when>
				<xsl:otherwise>
					<xsl:value-of select="$generated_directory_path"/>
				</xsl:otherwise>
			</xsl:choose>
		</xsl:if>
		<xsl:text>statistics.xml</xsl:text>
	</xsl:template>
	<!--Writes the XML document that holds the statistics page of the web site-->
	<xsl:template name="_write_statistics_xml_document_file">
		<xsl:if test="$generate_php = 'yes'">
			<xsl:variable name="file_path">
				<xsl:call-template name="_print_xml_document_statistics_file_path">
					<xsl:with-param name="url" select="'no'"/>
					<xsl:with-param name="relative" select="'no'"/>
				</xsl:call-template>
			</xsl:variable>
			<xsl:document href="{$file_path}">
				<Document ID="statistics">
					<Info/>
					<Abstract>This section provides information concerning the statistics of this site.</Abstract>
					<Title short="Stats">Statistics</Title>
					<Body>
						<p>
							<PHP>
								<xsl:text>require_once("php/common.php");
$database = connect_to_db("</xsl:text>
								<xsl:value-of select="$mysql_host_name"/>
								<xsl:text>", "</xsl:text>
								<xsl:value-of select="$mysql_user_name"/>
								<xsl:text>", "</xsl:text>
								<xsl:value-of select="$mysql_user_password"/>
								<xsl:text>", "</xsl:text>
								<xsl:value-of select="$mysql_database_name"/>
								<xsl:text>");
print_site_statistics($database);</xsl:text>
							</PHP>
						</p>
					</Body>
				</Document>
			</xsl:document>
		</xsl:if>
	</xsl:template>
</xsl:stylesheet>
